# A Comprehensive Software Stack for Condensed Matter Physics

This page contains links and suggestions for useful libraries and facilities to perform data analysis and theory calculations,
or to facilitate communication of work in condensed matter physics. Suggestions for additions are warmly appreciated.

## Generally Invaluable

1. [ASE (The Atomic Simulation Environment)](https://wiki.fysik.dtu.dk/ase/)
2. [xarray](https://xarray.pydata.org/en/stable/)
3. [SciPy/NumPy/pandas/Matplotlib](https://scipy.org)

## Theory

1. [pymatgen (Python Materials Genomics)](http://pymatgen.org/)
2. [GPAW](https://wiki.fysik.dtu.dk/gpaw/)

## Experiment and Analysis

1. [PyARPES](https://arpes.netlify.com)
2. [LMFIT](https://lmfit.github.io/lmfit-py/)
3. [scikit-learn](https://scikit-learn.org/stable/)

## Communicating

1. [Bokeh](https://bokeh.pydata.org/en/latest/)
2. [Seaborn](https://seaborn.pydata.org/)
3. Jupyter Notebook Presentations/RISE 

# Resources outside the Python Universe

1. [VESTA](http://jp-minerals.org/vesta/en/), largely redundant with ASE
2. [WSxM](http://www.wsxm.es/)